==> intentkit-0.6.9.dev2-py3-none-any.whl: intentkit/skills/supabase/invoke_function.py <==
import logging
from typing import Any, Dict, Optional, Type

from langchain_core.runnables import RunnableConfig
from langchain_core.tools import ToolException
from pydantic import BaseModel, Field
from supabase import Client, create_client

from intentkit.skills.supabase.base import SupabaseBaseTool

NAME = "supabase_invoke_function"
PROMPT = "Invoke a Supabase Edge Function with optional parameters."

logger = logging.getLogger(__name__)


class SupabaseInvokeFunctionInput(BaseModel):
    """Input for SupabaseInvokeFunction tool."""

    function_name: str = Field(description="The name of the Edge Function to invoke")
    parameters: Optional[Dict[str, Any]] = Field(
        default=None, description="Optional parameters to pass to the function"
    )
    headers: Optional[Dict[str, str]] = Field(
        default=None, description="Optional headers to include in the request"
    )


class SupabaseInvokeFunction(SupabaseBaseTool):
    """Tool for invoking Supabase Edge Functions.

    This tool allows calling Supabase Edge Functions with optional parameters and headers.
    """

    name: str = NAME
    description: str = PROMPT
    args_schema: Type[BaseModel] = SupabaseInvokeFunctionInput

    async def _arun(
        self,
        function_name: str,
        parameters: Optional[Dict[str, Any]] = None,
        headers: Optional[Dict[str, str]] = None,
        config: RunnableConfig = None,
        **kwargs,
    ):
        try:
            context = self.context_from_config(config)
            supabase_url, supabase_key = self.get_supabase_config(
                context.config, context
            )

            # Create Supabase client
            supabase: Client = create_client(supabase_url, supabase_key)

            # Prepare function invocation parameters
            invoke_options = {}
            if parameters:
                invoke_options["json"] = parameters
            if headers:
                invoke_options["headers"] = headers

            # Invoke the Edge Function
            response = supabase.functions.invoke(function_name, invoke_options)

            return {
                "success": True,
                "data": response.json() if hasattr(response, "json") else response,
                "status_code": getattr(response, "status_code", None),
            }

        except Exception as e:
            logger.error(f"Error invoking Supabase Edge Function: {str(e)}")
            raise ToolException(
                f"Failed to invoke Edge Function '{function_name}': {str(e)}"
            )

==> intentkit-0.6.11.dev4-py3-none-any.whl: intentkit/skills/supabase/invoke_function.py <==
import logging
from typing import Any, Dict, Optional, Type

from langchain_core.tools import ToolException
from pydantic import BaseModel, Field
from supabase import Client, create_client

from intentkit.skills.supabase.base import SupabaseBaseTool

NAME = "supabase_invoke_function"
PROMPT = "Invoke a Supabase Edge Function with optional parameters."

logger = logging.getLogger(__name__)


class SupabaseInvokeFunctionInput(BaseModel):
    """Input for SupabaseInvokeFunction tool."""

    function_name: str = Field(description="The name of the Edge Function to invoke")
    parameters: Optional[Dict[str, Any]] = Field(
        default=None, description="Optional parameters to pass to the function"
    )
    headers: Optional[Dict[str, str]] = Field(
        default=None, description="Optional headers to include in the request"
    )


class SupabaseInvokeFunction(SupabaseBaseTool):
    """Tool for invoking Supabase Edge Functions.

    This tool allows calling Supabase Edge Functions with optional parameters and headers.
    """

    name: str = NAME
    description: str = PROMPT
    args_schema: Type[BaseModel] = SupabaseInvokeFunctionInput

    async def _arun(
        self,
        function_name: str,
        parameters: Optional[Dict[str, Any]] = None,
        headers: Optional[Dict[str, str]] = None,
        **kwargs,
    ):
        try:
            context = self.get_context()
            skill_config = context.agent.skill_config(self.category)
            supabase_url, supabase_key = self.get_supabase_config(skill_config, context)

            # Create Supabase client
            supabase: Client = create_client(supabase_url, supabase_key)

            # Prepare function invocation parameters
            invoke_options = {}
            if parameters:
                invoke_options["json"] = parameters
            if headers:
                invoke_options["headers"] = headers

            # Invoke the Edge Function
            response = supabase.functions.invoke(function_name, invoke_options)

            return {
                "success": True,
                "data": response.json() if hasattr(response, "json") else response,
                "status_code": getattr(response, "status_code", None),
            }

        except Exception as e:
            logger.error(f"Error invoking Supabase Edge Function: {str(e)}")
            raise ToolException(
                f"Failed to invoke Edge Function '{function_name}': {str(e)}"
            )
